@@ -1,4 +1,4 @@
-from tsdat.config import Config, Keys, QualityTestDefinition
+from tsdat.config import Config, Keys, QualityManagerDefinition
 from tsdat.io.storage import DatastreamStorage
 from tsdat.io.filesystem_storage import FilesystemStorage
 from tsdat.io.aws_storage import AwsStorage
