@@ -5,6 +5,7 @@ import pathlib
 import zipfile
 
 import datetime
+import _strptime # added to workaround https://bugs.python.org/issue8098, causes issues on some machines
 import os
 import shutil
 import xarray as xr
@@ -40,8 +41,13 @@ class FilesystemTemporaryStorage(TemporaryStorage):
 
         for filepath in files:
             is_file = os.path.isfile(filepath)
-            is_tar = tarfile.is_tarfile(filepath) # tar or tar.gz
-            is_zip = zipfile.is_zipfile(filepath)
+
+            if self.ignore_zip_check(filepath):
+                is_tar = False
+                is_zip = False
+            else:
+                is_tar = tarfile.is_tarfile(filepath) # tar or tar.gz
+                is_zip = zipfile.is_zipfile(filepath)
 
             if is_tar or is_zip:
                 # only dispose of the parent zip if set by storage policy
